import React, { FC } from 'react';
export declare type ParentComponentsContextType = string[];
/**
 * Context for tracking parent elements in the React component tree.
 */
declare const ParentComponentsContext: React.Context<ParentComponentsContextType>;
export interface ParentComponentsProviderProps {
    /**
     * The name of the current component to register to the tracked component tree.
     */
    componentName: string;
    children: React.ReactNode;
}
/**
 * Provider to wrap around components you would like to check for in the component tree by a child component.
 */
export declare const ParentComponentsContextProvider: FC<ParentComponentsProviderProps>;
/**
 * Hook to retrieve an ordered list of the tracked ancestors of the current component.
 * Ordered from furthest -> closest ancestor.
 * @returns The list of parent component names.
 */
export declare const useParentComponents: () => ParentComponentsContextType;
export default ParentComponentsContext;
