import type { InternalOcNamePath, OcNamePath, OcStore, OcStoreValue, OcEventArgs } from '../OcForm.types';
/**
 * Convert name to internal supported format.
 * This function should keep since we still thinking if need support like `a.b.c` format.
 * 'a' => ['a']
 * 123 => [123]
 * ['a', 123] => ['a', 123]
 */
export declare function getNamePath(path: OcNamePath | null): InternalOcNamePath;
export declare function getValue(store: OcStore, namePath: InternalOcNamePath): (entity: any, path: (string | number)[]) => any;
export declare function setValue(store: OcStore, namePath: InternalOcNamePath, value: OcStoreValue, removeIfUndefined?: boolean): OcStore;
export declare function cloneByNamePathList(store: OcStore, namePathList: InternalOcNamePath[]): OcStore;
export declare function containsNamePath(namePathList: InternalOcNamePath[], namePath: InternalOcNamePath): boolean;
export declare function setValues<T>(store: T, ...restValues: T[]): T;
export declare function matchNamePath(namePath: InternalOcNamePath, changedNamePath: InternalOcNamePath | null): boolean;
declare type SimilarObject = string | number | {};
export declare function isSimilar(source: SimilarObject, target: SimilarObject): boolean;
export declare function defaultGetValueFromEvent(valuePropName: string, ...args: OcEventArgs): any;
/**
 * Moves an array item from one position in an array to another.
 *
 * Note: This is a pure function so a new array will be returned, instead
 * of altering the array argument.
 *
 * @param array         Array in which to move an item.         (required)
 * @param moveIndex     The index of the item to move.          (required)
 * @param toIndex       The index to move item at moveIndex to. (required)
 */
export declare function move<T>(array: T[], moveIndex: number, toIndex: number): T[];
export {};
