import type { OcFormInstance, InternalOcFormInstance, InternalOcNamePath, OcStoreValue } from './OcForm.types';
interface UpdateAction {
    type: 'updateValue';
    namePath: InternalOcNamePath;
    value: OcStoreValue;
}
interface ValidateAction {
    type: 'validateField';
    namePath: InternalOcNamePath;
    triggerName: string;
}
export declare type ReducerAction = UpdateAction | ValidateAction;
export declare class FormStore {
    private formHooked;
    private forceRootUpdate;
    private subscribable;
    private store;
    private fieldEntities;
    private initialValues;
    private callbacks;
    private validateMessages;
    private preserve?;
    private lastValidatePromise;
    constructor(forceRootUpdate: () => void);
    getForm: () => InternalOcFormInstance;
    private getInternalHooks;
    private useSubscribe;
    /**
     * Record prev Form unmount fieldEntities which config preserve false.
     * This need to be refill with initialValues instead of store value.
     */
    private prevWithoutPreserves;
    /**
     * First time `setInitialValues` should update store with initial value
     */
    private setInitialValues;
    private destroyForm;
    private getInitialValue;
    private setCallbacks;
    private setValidateMessages;
    private setPreserve;
    private watchList;
    private registerWatch;
    private notifyWatch;
    private updateStore;
    /**
     * Get registered field entities.
     * @param pure Only return field which has a `name`. Default: false
     */
    private getFieldEntities;
    private getFieldsMap;
    private getFieldEntitiesForNamePathList;
    private getFieldListValues;
    private getFieldValue;
    private getFieldListErrors;
    private getFieldError;
    private getFieldWarning;
    private isListTouched;
    private isTouched;
    private isListValidating;
    private isValidating;
    /**
     * Reset Field with field `initialValue` prop.
     * Can pass `entities` or `namePathList` or just nothing.
     */
    private resetWithFieldInitialValue;
    private resetFields;
    private setFields;
    private getFields;
    /**
     * This only trigger when a field is on constructor to avoid we get initialValue too late
     */
    private initEntityValue;
    private isMergedPreserve;
    private registerField;
    private dispatch;
    private notifyObservers;
    /**
     * Notify dependencies children with parent update
     * We need delay to trigger validate in case Field is under render props
     */
    private triggerDependenciesUpdate;
    private updateValue;
    private setFieldListValues;
    private setFieldValue;
    private getDependencyChildrenFields;
    private triggerOnFieldsChange;
    private validateFields;
    private submit;
}
declare function useForm<Values = any>(form?: OcFormInstance<Values>): [OcFormInstance<Values>];
export default useForm;
