import React from 'react';
import { OcTreeProps, OcTreeState } from './OcTree.types';
import { NodeMouseEventHandler, NodeDragEventHandler } from './contextTypes';
import { DataNode, Key, FlattenNode, EventDataNode, NodeInstance, ScrollTo, BasicDataNode } from './OcTree.types';
import { NodeListRef } from './NodeList';
declare class Tree<TreeDataType extends DataNode | BasicDataNode = DataNode> extends React.Component<OcTreeProps<TreeDataType>, OcTreeState<TreeDataType>> {
    static defaultProps: any;
    static TreeNode: React.FC<import("./OcTree.types").TreeNodeProps<DataNode>>;
    destroyed: boolean;
    delayedDragEnterLogic: Record<Key, number>;
    loadingRetryTimes: Record<Key, number>;
    state: OcTreeState<TreeDataType>;
    dragStartMousePosition: {
        x: number;
        y: number;
    };
    dragNode: NodeInstance<TreeDataType>;
    currentMouseOverDroppableNodeKey: Key;
    listRef: React.RefObject<NodeListRef>;
    componentDidMount(): void;
    componentDidUpdate(): void;
    onUpdated(): void;
    componentWillUnmount(): void;
    static getDerivedStateFromProps(props: OcTreeProps, prevState: OcTreeState): Partial<OcTreeState<DataNode>>;
    onNodeDragStart: NodeDragEventHandler<TreeDataType, HTMLDivElement>;
    /**
     * [Legacy] Select handler is smaller than node,
     * so that this will trigger when drag enter node or select handler.
     * This is a little tricky if customize css without padding.
     * Better for use mouse move event to refresh drag state.
     * But let's just keep it to avoid event trigger logic change.
     */
    onNodeDragEnter: (event: React.DragEvent<HTMLDivElement>, node: NodeInstance<TreeDataType>) => void;
    onNodeDragOver: (event: React.DragEvent<HTMLDivElement>, node: NodeInstance<TreeDataType>) => void;
    onNodeDragLeave: NodeDragEventHandler<TreeDataType>;
    onWindowDragEnd: (event: React.DragEvent<HTMLDivElement>) => void;
    onNodeDragEnd: NodeDragEventHandler<TreeDataType>;
    onNodeDrop: (event: React.DragEvent<HTMLDivElement>, _node: any, outsideTree?: boolean) => void;
    resetDragState(): void;
    cleanDragState: () => void;
    triggerExpandActionExpand: NodeMouseEventHandler;
    onNodeClick: NodeMouseEventHandler;
    onNodeDoubleClick: NodeMouseEventHandler;
    onNodeSelect: NodeMouseEventHandler<TreeDataType>;
    onNodeCheck: (e: React.MouseEvent<HTMLSpanElement>, treeNode: EventDataNode<TreeDataType>, checked: boolean) => void;
    onNodeLoad: (treeNode: EventDataNode<TreeDataType>) => Promise<void>;
    onNodeMouseEnter: NodeMouseEventHandler<TreeDataType>;
    onNodeMouseLeave: NodeMouseEventHandler<TreeDataType>;
    onNodeContextMenu: NodeMouseEventHandler<TreeDataType>;
    onFocus: React.FocusEventHandler<HTMLDivElement>;
    onBlur: React.FocusEventHandler<HTMLDivElement>;
    getTreeNodeRequiredProps: () => {
        expandedKeys: Key[];
        selectedKeys: Key[];
        loadedKeys: Key[];
        loadingKeys: Key[];
        checkedKeys: Key[];
        halfCheckedKeys: Key[];
        dragOverNodeKey: Key;
        dropPosition: 0 | 1 | -1;
        keyEntities: Record<Key, import("./OcTree.types").DataEntity<TreeDataType>>;
    };
    /** Set uncontrolled `expandedKeys`. This will also auto update `flattenNodes`. */
    setExpandedKeys: (expandedKeys: Key[]) => void;
    onNodeExpand: (e: React.MouseEvent<HTMLDivElement>, treeNode: EventDataNode<TreeDataType>) => void;
    onListChangeStart: () => void;
    onListChangeEnd: () => void;
    onActiveChange: (newActiveKey: Key) => void;
    getActiveItem: () => FlattenNode<TreeDataType>;
    offsetActiveKey: (offset: number) => void;
    onKeyDown: React.KeyboardEventHandler<HTMLDivElement>;
    /**
     * Only update the value which is not in props
     */
    setUncontrolledState: (state: Partial<OcTreeState<TreeDataType>>, atomic?: boolean, forceState?: Partial<OcTreeState<TreeDataType>> | null) => void;
    scrollTo: ScrollTo;
    render(): React.JSX.Element;
}
export default Tree;
