declare type Updater<T> = T | ((prevValue: T) => T);
export declare type SetState<T> = (nextValue: Updater<T>, 
/**
 * Will not update state when destroyed.
 * Developer should make sure this is safe to ignore.
 */
ignoreDestroy?: boolean) => void;
/**
 * Same as React.useState but `setState` accept `ignoreDestroy` param to not to setState after destroyed.
 * We do not make this auto is to avoid a real memory leak.
 * Developer should confirm it's safe to ignore themselves.
 */
export declare const useSafeState: <T>(defaultValue?: T | (() => T)) => [T, SetState<T>];
export declare const useRefState: <T>(defaultValue: T) => [T, SetState<T>];
export {};
